@@ -27,6 +27,22 @@
 using namespace ucommon;
 
 static int tval = 100;
+static int dval = 0;
+static int cval = 0;
+
+class special
+{
+public:
+    int x;
+    
+    special() {
+        x = ++cval;
+    }
+
+    ~special() {
+        ++dval;
+    }
+};
 
 extern "C" int main()
 {
@@ -59,5 +75,33 @@ extern "C" int main()
     int& rval = deref_pointer<int>(pval);
     assert(&rval == pval);
 
+    typeref<int> iptr;
+    iptr = (int)3;
+    typeref<int> jptr = iptr;
+    assert((int)iptr == 3);
+    assert(iptr.copies() == 2);
+
+    iptr = 17;
+    assert((int)iptr == 17);
+    assert(iptr.copies() == 1);
+
+    special spec;
+    cval = 0;
+    typeref<special> sptr = spec;
+    typeref<special> xptr = sptr;
+    assert(xptr->x == 1);
+    assert(cval == 1);
+    assert(xptr.copies() == 2);
+    sptr.release();
+    xptr.release();
+    assert(dval == 1);
+
+    stringref sref = "this is a test";
+    stringref xref = sref;
+    assert(*sref == *xref);
+    assert(!strcmp((const char *)sref, "this is a test"));
+    assert(sref.size() == 14);
+    assert(sref.copies() == 2);
+
     return 0;
 }
