@@ -35,6 +35,11 @@ extern "C" int main()
     unsigned count = 0;
     const char *tp;
     const char *array[5];
+    stringref_t sref = "ABC";
+    string_t tref(sref);
+
+    assert(eq(tref, "ABC"));
+    assert(eq(sref, "ABC"));
 
     assert(max(3, 2) == 3);
 
@@ -99,5 +104,19 @@ extern "C" int main()
     strfree(test);
     strfree(cdup);
 
+    stringref_t cvs;
+    charvalues_t cv1 = stringref::create(64);
+    charvalues_t cv2 = cv1;
+
+    snprintf(cv1->get(), cv1->max(), "test %d\n", 1);
+    stringref::expand(&cv1, 64);
+    assert(cv1->max() == 128);
+    assert(cv2 != cv1);
+    assert(eq(cv1->get(), "test 1\n"));
+    cvs.assign(cv1);
+    assert(cvs.copies() == 1);
+    assert(eq(cvs, "test 1\n"));
+    assert(cvs.size() == 7);
+
     return 0;
 }
